summaryrefslogtreecommitdiff
path: root/src/analysis/scan/match-int.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/analysis/scan/match-int.h')
-rw-r--r--src/analysis/scan/match-int.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/src/analysis/scan/match-int.h b/src/analysis/scan/match-int.h
index 9030d75..cf774c4 100644
--- a/src/analysis/scan/match-int.h
+++ b/src/analysis/scan/match-int.h
@@ -29,8 +29,11 @@
-/* Affiche une correspondance sur la sortie standard. */
-typedef void (* display_scan_match_fc) (const GScanMatch *);
+/* Affiche une correspondance au format texte. */
+typedef void (* output_scan_match_to_text_fc) (const GScanMatch *, int);
+
+/* Affiche une correspondance au format JSON. */
+typedef void (* output_scan_match_to_json_fc) (const GScanMatch *, const sized_string_t *, unsigned int, int);
/* Correspondance trouvée avec un motif (instance) */
@@ -47,7 +50,8 @@ struct _GScanMatchClass
{
GObjectClass parent; /* A laisser en premier */
- display_scan_match_fc display; /* Impression des résultats */
+ output_scan_match_to_text_fc to_text; /* Impression au format texte */
+ output_scan_match_to_json_fc to_json; /* Impression au format JSON */
};